@@ -2,14 +2,15 @@ package VRML;
 
 require 5.000;
 
-$VERSION="0.92"; warn $VERSION if 0;
+$VERSION="0.94"; warn $VERSION if 0;
 
 sub new {
     my $class = shift;
     my ($version) = @_ ? @_ : 0;
     my $self;
     if ($version == 2 || $version =~ /2.0/) {
-	$::content_type = "model/vrml";
+#	$::content_type = "model/vrml";
+	$::content_type = "x-world/x-vrml";
 	require VRML::VRML2;
 	@ISA = qw(VRML::VRML2);
 	$self = new VRML::VRML2;
